import { useContext } from "react";
import { todosContext } from "../../context";
import getSearchTodos from "../../utils/todos/getSearchTodos";
import getTodos from "../../utils/todos/getTodos";
import getTodosSort from "../../utils/todos/getTodosSort";
import styles from "./Footer.module.css";

const Footer = () => {
  const { page, setPage, setTodos, search, sortCategory } =
    useContext(todosContext);

  const navigatePages = (page) => {
    if (!search && !sortCategory) {
      getTodos(page).then((result) => {
        setTodos(result.todos);
        setPage(result.page);
      });
    } else if (!sortCategory) {
      getSearchTodos(search, page).then((result) => {
        console.log(result.page);
        setTodos(result.todos);
        setPage(result.page);
      });
    } else if (!search) {
      getTodosSort(sortCategory, page).then((result) => {
        setTodos(result.todos);
        setPage(result.page);
      });
    } else {
      console.log(12345);
    }
  };

  console.log(page.current, page.previous, page.next, page.total);

  return (
    <>
      {page.total ? (
        <div className={styles.button_nav}>
          <button
            onClick={() => navigatePages(page.previous)}
            disabled={page.previous === undefined && true}
          >
            Back
          </button>
          <div className={styles.button_num}>
            {new Array(page.total)
              .fill()
              .map((_, i) => i + 1)
              .map((p) => {
                return (
                  <button
                    key={p}
                    style={{
                      color: `${p === page.current ? "#499557" : "#C4C4C4"}`,
                      textDecoration: `${
                        p === page.current ? "underline" : "none"
                      }`,
                    }}
                    onClick={() => navigatePages(p)}
                  >
                    {p}
                  </button>
                );
              })}
          </div>
          <button
            onClick={() => navigatePages(page.next)}
            disabled={page.next === undefined && true}
          >
            Next
          </button>
        </div>
      ) : (
        ""
      )}
    </>
  );
};

export default Footer;
